# [Zope-tests] OK : Zope Buildbot / zopetoolkit-1.0_win-py2.5 slave-win

jdriessen at thehealthagency.com jdriessen at thehealthagency.com
Thu Feb 3 01:13:09 EST 2011

- Previous message: [Zope-tests] OK : Zope-2.12-alltests Python-2.6.5 : Linux
- Next message: [Zope-tests] OK : Zope-2.13 Python-2.6.5 : Linux
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

    OK : Zope Buildbot / zopetoolkit-1.0_win-py2.5 slave-win
    Build: http://dev.thehealthagency.com/buildbot/builders/zopetoolkit-1.0_win-py2.5%20slave-win/builds/111

    Build Reason: The Periodic scheduler named 'Periodic scheduler for zopetoolkit-1.0_win-py2.5' triggered this build

    Build Source Stamp: HEAD

    Blamelist:

    Buildbot: http://dev.thehealthagency.com/buildbot/

- Previous message: [Zope-tests] OK : Zope-2.12-alltests Python-2.6.5 : Linux
- Next message: [Zope-tests] OK : Zope-2.13 Python-2.6.5 : Linux
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

More information about the Zope-tests mailing list